@@ -12,7 +12,7 @@ package MooX::Options::Role;
 use strict;
 use warnings;
 
-our $VERSION = '3.0';    # VERSION
+our $VERSION = '3.1';    # VERSION
 
 use MRO::Compat;
 use Moo::Role;
@@ -107,7 +107,8 @@ sub parse_options {
     }
 
     if (@missing_required) {
-        print join( "\n", map { $_ . " is missing" } @missing_required, '' );
+        print join( "\n", ( map { $_ . " is missing" } @missing_required ),
+            '' );
         print $usage, "\n";
         exit(1);
     }
@@ -145,7 +146,7 @@ MooX::Options::Role - role that is apply to your object
 
 =head1 VERSION
 
-version 3.0
+version 3.1
 
 =head1 METHODS
 
